<?php
/**
 * A default listener pool
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class DefaultListenerPool extends BasePool implements PoolableListener {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$nodeInstance		A NodeHelper instance
	 * @return	$listenerInstance	An instance a prepared listener class
	 */
	public static final function createDefaultListenerPool (NodeHelper $nodeInstance) {
		// Get new instance
		$listenerInstance = new DefaultListenerPool();

		// Return the prepared instance
		return $listenerInstance;
	}

	/**
	 * Adds a listener instance to this pool
	 *
	 * @param	$listenerInstance	An instance of a Listenable class
	 * @return	void
	 */
	public function addListener (Listenable $listenerInstance) {
		// Add this listener instance to the instance list
		parent::addInstance($listenerInstance->getProtocolName(), 'listener', $listenerInstance);

		// Debug message
		self::createDebugInstance(__CLASS__)->debugOutput(
			'POOL[' . __METHOD__ . ':' . __LINE__ . ']: Listener ' . $listenerInstance->__toString() .
			' listening to ' . $listenerInstance->getListenAddress() . ':' .
			$listenerInstance->getListenPort() . ' added to listener pool.'
		);
	}

	/**
	 * Run the shutdown seqeuence by a Visitor Pattern
	 *
	 * @return	void
	 */
	public function doShutdown () {
		// Debug message
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('POOL[' . __METHOD__ . ':' . __LINE__ . ']: Shutting down listener pool - CALLED!');

		// Get a new visitor
		$visitorInstance = ObjectFactory::createObjectByConfiguredName('shutdown_listener_pool_visitor_class');

		// Start visiting
		$this->accept($visitorInstance);

		// Debug message
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('POOL[' . __METHOD__ . ':' . __LINE__ . ']: Shutting down listener pool - EXIT!');
	}
}

// [EOF]
?>
