<?php
/**
 * A general DHT state class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 * @todo		Create generic DHT interface
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class BaseDhtState extends BaseState {
	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * Validates whether the DHT state is 'virgin' or throws an exception if it
	 * is every other state.
	 *
	 * @return	void
	 * @throws	UnexpectedStateException	If the state is not 'virgin'
	 */
	public function validateDhtStateIsVirginOrInit () {
		// Just compare it...
		if ((!$this instanceof DhtVirginState) && (!$this instanceof DhtInitState)) {
			// Throw the exception
			throw new UnexpectedStateException($this, self::EXCEPTION_INVALID_STATE);
		} // END - if
	}

	/**
	 * Checks whether the DHT's state is 'booting' by comparing it with the
	 * state's class name.
	 *
	 * @return	$isBooting	Whether this DHT's state is 'booting'
	 */
	public function ifDhtIsBooting () {
		// Check state
		$isBooting = ($this instanceof DhtBootingState);

		// Return status
		return $isBooting;
	}
}

// [EOF]
?>
