<?php
/**
 * A RawDataMonitor visitor
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class RawDataPoolMonitorVisitor extends BaseVisitor implements PoolVisitor, ListenerVisitor {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set visitor mode
		$this->setVisitorMode('monitor');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$receiverInstance	An instance of a Receivable class
	 * @return	$visitorInstance	An instance of a Visitorable class
	 */
	public final static function createRawDataPoolMonitorVisitor () {
		// Get new instance
		$visitorInstance = new RawDataPoolMonitorVisitor();

		// Return the prepared instance
		return $visitorInstance;
	}

	/**
	 * Visits the given pool instance
	 *
	 * @param	$poolInstance	A Poolable instance
	 * @return	void
	 */
	public function visitPool (Poolable $poolInstance) {
		// A pool doesn't normally have any raw data waiting
		//* DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: poolInstance=' . $poolInstance->__toString() . ' - CALLED!');
	}

	/**
	 * Visits the given listener instance
	 *
	 * @param	$listenerInstance	A Listenable instance
	 * @return	void
	 */
	public function visitListener (Listenable $listenerInstance) {
		/*
		 * The listener itself cannot distinguish between node and client
		 * traffic. This is why its method monitorIncomingRawData() is not
		 * called.
		 */
		//* DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: listenerInstance=' . $listenerInstance->__toString() . ' - CALLED!');
	}

	/**
	 * Visits the given decorator instance
	 *
	 * @param	$decoratorInstance	A decorator instance
	 * @return	void
	 */
	public function visitDecorator (BaseDecorator $decoratorInstance) {
		// Do monitor here
		//* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: Visiting ' . $listenerInstance->__toString() . ' - CALLED!');
		$decoratorInstance->monitorIncomingRawData();
		//* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: Visiting ' . $listenerInstance->__toString() . ' - FINISH');
	}
}

// [EOF]
?>
