<?php
/**
 * An interface for DHTs
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface DistributableNode extends Distributable {
	/**
	 * Finds a node locally by given session id
	 *
	 * @param	$sessionId	Session id to lookup
	 * @return	$nodeData	Node-data array
	 */
	function findNodeLocalBySessionId ($sessionId);

	/**
	 * Registers an other node with this node by given message data. The
	 * following data must always be present:
	 *
	 * - session-id  (for finding the node's record together with below data)
	 * - external-address (hostname or IP number)
	 * - listen-port (TCP/UDP listen port for inbound connections)
	 *
	 * @param	$messageData		An array with all minimum message data
	 * @param	$handlerInstance	An instance of a HandleableDataSet class
	 * @param	$forceUpdate		Optionally force update, don't register (default: register if not found)
	 * @return	void
	 */
	function registerNodeByMessageData (array $messageData, HandleableDataSet $handlerInstance, $forceUpdate = FALSE);

	/**
	 * Queries the local DHT data(base) for a node list with all supported
	 * object types except the node by given session id.
	 *
	 * @param	$messageData		An array with message data from a node_list request
	 * @param	$handlerInstance	An instance of a HandleableDataSet class
	 * @param	$excludeKey			Array key which should be excluded
	 * @param	$andKey				Array of $separator-separated list of elements which all must match
	 * @param	$separator			Sepator char (1st parameter for explode() call)
	 * @return	$nodeList			An array with all found nodes
	 */
	function queryLocalNodeListExceptByMessageData (array $messageData, HandleableDataSet $handlerInstance, $excludeKey, $andKey, $separator);

	/**
	 * Inserts given node list array (from earlier database result produced by
	 * an other node) into the DHT. This array origins from above method
	 * queryLocalNodeListExceptByMessageData().
	 *
	 * @param	$nodeList	An array from an earlier database result instance
	 * @return	void
	 */
	function insertNodeList (array $nodeList);

	/**
	 * Checks whether there are entries in "INSERT" node data stack
	 *
	 * @return	$isPending	Whether there are pending entries
	 */
	function ifInsertNodeDataPending ();

	/**
	 * Checks whether there are unpublished entries
	 *
	 * @return	$hasUnpublished		Whether there are unpublished entries
	 */
	function hasUnpublishedEntries ();

	/**
	 * Initializes publication of DHT entries. This does only prepare
	 * publication. The next step is to pickup such prepared entries and publish
	 * them by uploading to other (recently appeared) DHT members.
	 *
	 * @return	void
	 */
	function initEntryPublication ();

	/**
	 * Checks whether there are entries pending publication
	 *
	 * @return	$isPending	Whether there are entries pending publication
	 */
	function hasEntriesPendingPublication ();

	/**
	 * Publishes next entry found in stack. This method shall also update the
	 * corresponding dabase entry.
	 *
	 * @return	void
	 */
	function publishEntry ();
}

// [EOF]
?>
